@@ -89,6 +89,7 @@ __all__ = (
     "RebootBrokerResponseTypeDef",
     "UpdateBrokerCountResponseTypeDef",
     "UpdateBrokerStorageResponseTypeDef",
+    "UpdateBrokerTypeResponseTypeDef",
     "UpdateClusterConfigurationResponseTypeDef",
     "UpdateClusterKafkaVersionResponseTypeDef",
     "UpdateConfigurationResponseTypeDef",
@@ -312,6 +313,7 @@ MutableClusterInfoTypeDef = TypedDict(
         "OpenMonitoring": "OpenMonitoringTypeDef",
         "KafkaVersion": str,
         "LoggingInfo": "LoggingInfoTypeDef",
+        "InstanceType": str,
     },
     total=False,
 )
@@ -570,6 +572,10 @@ UpdateBrokerStorageResponseTypeDef = TypedDict(
     total=False,
 )
 
+UpdateBrokerTypeResponseTypeDef = TypedDict(
+    "UpdateBrokerTypeResponseTypeDef", {"ClusterArn": str, "ClusterOperationArn": str}, total=False
+)
+
 UpdateClusterConfigurationResponseTypeDef = TypedDict(
     "UpdateClusterConfigurationResponseTypeDef",
     {"ClusterArn": str, "ClusterOperationArn": str},
